@@ -4,7 +4,7 @@ import numpy as np
 def im2dhisteq(image, w_neighboring=6):
     [h, w] = image.shape
     V = image.copy()
-    V_hist = imhist(V.reshape(1, -1))
+    V_hist = imhist(V)
 
     H_in = im2dhist(V, w_neighboring=6)
 
